@@ -5,22 +5,22 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.213 ;
+use IO::Compress::Base 2.217 ;
 
-use IO::Compress::Base::Common  2.213 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Lzma 2.213 ;
+use IO::Compress::Base::Common  2.217 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Lzma 2.217 ;
 
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzmaError);
 
-$VERSION = '2.213';
+$VERSION = '2.217';
 $LzmaError = '';
 
 @ISA    = qw(IO::Compress::Base Exporter);
 @EXPORT_OK = qw( $LzmaError lzma ) ;
 %EXPORT_TAGS = %IO::Compress::Base::EXPORT_TAGS ;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 Exporter::export_ok_tags('all');
 
 
@@ -831,7 +831,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2026 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
